#ifndef NT2_INCLUDE_FUNCTIONS_ISEXPANDABLE_TO_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISEXPANDABLE_TO_HPP_INCLUDED

#include <nt2/predicates/include/functions/isexpandable_to.hpp>

#endif
